Crate cnctd_solana

Crate cnctd_solana 

Re-exports

pub use crate::utils::get_associated_token_address_with_program_id_address;

Modules

account
The Solana Account type.
account_info
Account information.
big_mod_exp
blake3
Hashing with the blake3 hash function.
blockhash_query
borsh1
Utilities for the borsh serialization format, version 1.
bpf_loader
The latest BPF loader native program.
bpf_loader_deprecated
The original and now deprecated Solana BPF loader.
bs58
Another Base58 codec implementation.
client_error
clock
Information about the network’s clock, ticks, slots, etc.
config
The config native program.
connection_cache
deserialize_utils
Serde helpers.
ed25519_program
The ed25519 native program.
entrypoint
The Rust-based BPF program entrypoint supported by the latest BPF loader.
entrypoint_deprecated
The Rust-based BPF program entrypoint supported by the original BPF loader.
epoch_info
Information about the current epoch.
epoch_rewards
A type to hold data for the EpochRewards sysvar.
epoch_rewards_hasher
epoch_schedule
error
fee
Fee structures.
fee_calculator
Calculation of transaction fees.
hash
Hashing with the SHA-256 hash function, and a general Hash type.
incinerator
inflation
configuration for network inflation
instruction
keccak
Hashing with the keccak (SHA-3) hash function.
lamports
Re-exports the LamportsError type for backwards compatibility.
log
message
Sequences of Instructions executed within a single transaction.
mock_sender_for_cli
native_loader
The native loader native program.
native_token
Definitions for the native SOL token and its fractional lamports.
nonblocking
nonce_utils
Durable transaction nonce helpers.
offchain_message
Off-chain message container for storing non-transaction messages.
program
Wrappers around solana-cpi with support for overwriting syscall stubs
program_error
program_memory
Basic low-level memory operations.
program_option
A C representation of Rust’s Option, used across the FFI boundary for Solana program interfaces.
program_pack
The Pack serialization trait This is a specific serialization API that is used by many older programs in the Solana Program Library to manage account state. It is not generally recommended for new code since it does not define a language-independent serialization format.
program_stubs
Implementations of syscalls used when solana-program is built for non-SBF targets.
pubkey
pubsub_client
rent
Configuration for network rent.
rpc
rpc_client
Communication with a Solana node over RPC.
rpc_config
rpc_custom_error
Implementation defined RPC server errors
rpc_filter
rpc_request
rpc_response
rpc_sender
A transport for RPC calls.
sanitize
A trait for sanitizing values and members of over the wire messages.
secp256k1_program
The secp256k1 native program.
send_and_confirm_transactions_in_parallel
serde_varint
Integers that serialize to variable size.
serialize_utils
Helpers for reading and writing bytes.
short_vec
Compact serde-encoding of vectors with small length.
shred_version
Calculation of shred versions.
signature
Functionality for public and private keys.
signer
simple_vote_transaction_checker
slot_hashes
slot_history
stable_layout
Types with stable memory layouts
system_instruction
Instructions and constructors for the system program.
sysvar
timing
std::time utility functions.
token
tpu_client
transaction
transaction_executor
transport
Defines the TransportError type.
utils

Macros

address
Convenience macro to define a static Address value.
custom_heap_default
Define the default global allocator.
custom_panic_default
Define the default global panic handler.
declare_deprecated_id
declare_deprecated_sysvar_id
Same as declare_sysvar_id except that it reports that this ID has been deprecated.
declare_id
declare_sysvar_id
Declares an ID that implements SysvarId.
impl_sysvar_get
Implements the Sysvar::get method for both SBF and host targets.
msg
Print a message to the log.
pubkey
Convenience macro to define a static Address value.
pubkeys
unchecked_div_by_const
Convenience macro for doing integer division where the operation’s safety can be checked at compile-time.

Structs

Address
The address of a Solana account.
AddressHasher
A faster, but less collision resistant hasher for addresses.
AddressHasherBuilder
A builder for faster, but less collision resistant hasher for addresses.
ParsedAccount
UiAccount
A duplicate representation of an Account for pretty JSON serialization
UiDataSliceConfig

Enums

ClusterType
ComputeBudgetInstruction
Compute Budget Instructions
UiAccountData
UiAccountEncoding

Constants

ADDRESS_BYTES
Number of bytes in an address.
ASSOCIATED_TOKEN_PROGRAM_ID
Associated Token Account program (interface crate) — same address
ID
The const program ID.
MAX_SEEDS
Maximum number of seeds
MAX_SEED_LEN
maximum length of derived Address seed
METAPLEX_METADATA_ADDRESS
MPL_TOKEN_METADATA_PROGRAM_ID
Metaplex Token Metadata
SPL_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM_ID
Associated Token Account program (classic crate)
SPL_TOKEN_PROGRAM_ID
SPL Token (legacy)
SPL_TOKEN_PROGRAM_ID_2022
SPL Token-2022
SYSTEM_PROGRAM_ID
System Program
SYSVAR_RENT_ID
Sysvar: Rent

Functions

bytes_are_curve_point
check_id
Returns true if given pubkey is the program ID.
get_associated_token_address
Derives the associated token account address for the given wallet address and token mint
get_associated_token_address_with_program_id
Derives the associated token account address for the given wallet address, token mint and token program id
id
Returns the program ID.